<?php

/**
 * Include WEN Customizer
 */
require trailingslashit( get_template_directory() ) . 'magzimum-customizer/init.php';

/**
 * Init customizer
 */
require trailingslashit( get_template_directory() ) . 'inc/init.php';


/**
 * Magzimum functions and definitions
 *
 * @package Magzimum
 */

/**
 * Set the content width based on the theme's design and stylesheet.
 */
if ( ! isset( $content_width ) ) {
	$content_width = 1140; /* pixels */
}

if ( ! function_exists( 'magzimum_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function magzimum_setup() {

	/*
	 * Make theme available for translation.
	 * Translations can be filed in the /languages/ directory.
	 * If you're building a theme based on Magzimum, use a find and replace
	 * to change 'magzimum' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'magzimum', get_template_directory() . '/languages' );

	// Add default posts and comments RSS feed links to head.
	add_theme_support( 'automatic-feed-links' );

  if ( function_exists( 'has_custom_logo' ) ) {
      /**
      * Setup Custom Logo Support for theme
      * Supported from WordPress version 4.5 onwards
      * More Info: https://make.wordpress.org/core/2016/03/10/custom-logo/
      */
      add_theme_support( 'custom-logo' );
    }

	/*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
	add_theme_support( 'title-tag' );

	/*
	 * Enable support for Post Thumbnails on posts and pages.
	 *
	 * @link http://codex.wordpress.org/Function_Reference/add_theme_support#Post_Thumbnails
	 */
	add_theme_support( 'post-thumbnails' );

  // Register image size for featured slider
  add_image_size( 'magzimum-slider', 750, 315, true );
  add_image_size( 'magzimum-thumb', 360, 150, true ); // Ratio 12:5
  add_image_size( 'magzimum-featured', 354, 275, true);

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus( array(
    'primary'  => esc_html__( 'Primary Menu', 'magzimum' ),
    'top'      => esc_html__( 'Top Menu', 'magzimum' ),
    'social'   => esc_html__( 'Social Menu', 'magzimum' ),
    'footer'   => esc_html__( 'Footer Menu', 'magzimum' ),
    'notfound' => esc_html__( '404 Menu', 'magzimum' ),
	) );

	/*
	 * Switch default core markup for search form, comment form, and comments
	 * to output valid HTML5.
	 */
	add_theme_support( 'html5', array(
		'search-form', 'comment-form', 'comment-list', 'gallery', 'caption',
	) );

	/*
	 * Enable support for Post Formats.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'image', 'video', 'quote', 'link',
	) );

	// Set up the WordPress core custom background feature.
	add_theme_support( 'custom-background', apply_filters( 'magzimum_custom_background_args', array(
		'default-color' => 'ffffff',
		'default-image' => '',
    'default-attachment'  => 'fixed',
    'default-position-x'  => 'center',
    'wp-head-callback'    => 'magzimum_custom_background'
	) ) );

  //WooCommerce support
  add_theme_support( 'woocommerce' );
  if ( class_exists( 'WooCommerce' ) ) {
      global $woocommerce;

      if( version_compare( $woocommerce->version, '3.0.0', ">=" ) ) {
          add_theme_support( 'wc-product-gallery-zoom' );
          add_theme_support( 'wc-product-gallery-lightbox' );
          add_theme_support( 'wc-product-gallery-slider' );
      }
  }
  /**
   * Enable support for footer widgets
   */
  add_theme_support( 'footer-widgets', 4 );

  // Include supports
  require get_template_directory() . '/inc/supports.php';

  global $magzimum_default_theme_options;
  $magzimum_default_theme_options = magzimum_get_default_theme_options();

  if ( is_admin() ) {
    require( get_template_directory() . '/updater/theme-updater.php' );
  }
}
endif; // magzimum_setup
add_action( 'after_setup_theme', 'magzimum_setup' );


function magzimum_logo_migrate() {
  $ver = get_theme_mod( 'logo_version', false );

  // Return if update has already been run
  if ( version_compare( $ver, '2' ) >= 0 ) {
    return;
  }

  /**
   * Get Theme Options Values
   */

  $options = magzimum_get_option( 'site_logo' );
  // If a logo has been set previously, update to use logo feature introduced in WordPress 4.5
  if ( function_exists( 'the_custom_logo' ) ) {
    if( isset( $options) && '' != $options) {
      // Since previous logo was stored a URL, convert it to an attachment ID
      $logo = attachment_url_to_postid( $options);

      if ( is_int( $logo ) ) {
        set_theme_mod( 'custom_logo', $logo );
      }
    }

      // Update to match logo_version so that script is not executed continously
    set_theme_mod( 'logo_version', '2' );
  }

}
add_action( 'after_setup_theme', 'magzimum_logo_migrate' );
/**
 * Register widget area.
 *
 * @link http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function magzimum_widgets_init() {
  register_sidebar( array(
    'name'          => esc_html__( 'Primary Sidebar', 'magzimum' ),
    'id'            => 'sidebar-1',
    'description'   => '',
    'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
  ) );
  register_sidebar( array(
    'name'          => esc_html__( 'Secondary Sidebar', 'magzimum' ),
    'id'            => 'sidebar-2',
    'description'   => '',
    'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
  ) );
  //Optional Sidebar for Hompeage instead of main sidebar
  register_sidebar( array(
    'name'          => esc_html__( 'Optional Homepage Sidebar', 'magzimum' ),
    'id'            => 'sidebar-optional-homepage',
    'description'   => esc_html__( 'This is Optional Sidebar for Homepage', 'magzimum' ),
    'before_widget' => '<aside id="%1$s" class="widget %2$s"><div class="widget-wrap">',
    'after_widget'  => '</div><!-- .widget-wrap --></aside><!-- #widget-default-search -->',
    'before_title'  => '<h4 class="widget-title">',
    'after_title'   => '</h4>',
  ) );

  //Optional Sidebar for Archive instead of main sidebar
  register_sidebar( array(
    'name'          => esc_html__( 'Optional Archive Sidebar', 'magzimum' ),
    'id'            => 'sidebar-optional-archive',
    'description'   => esc_html__( 'This is Optional Sidebar for Archive', 'magzimum' ),
    'before_widget' => '<aside id="%1$s" class="widget %2$s"><div class="widget-wrap">',
    'after_widget'  => '</div><!-- .widget-wrap --></aside><!-- #widget-default-search -->',
    'before_title'  => '<h4 class="widget-title">',
    'after_title'   => '</h4>',
  ) );

  //Optional Sidebar for Page instead of main sidebar
  register_sidebar( array(
    'name'          => esc_html__( 'Optional Page Sidebar', 'magzimum' ),
    'id'            => 'sidebar-optional-page',
    'description'   => esc_html__( 'This is Optional Sidebar for Page', 'magzimum' ),
    'before_widget' => '<aside id="%1$s" class="widget %2$s"><div class="widget-wrap">',
    'after_widget'  => '</div><!-- .widget-wrap --></aside><!-- #widget-default-search -->',
    'before_title'  => '<h4 class="widget-title">',
    'after_title'   => '</h4>',
  ) );

  //Optional Sidebar for Post instead of main sidebar
  register_sidebar( array(
    'name'          => esc_html__( 'Optional Post Sidebar', 'magzimum' ),
    'id'            => 'sidebar-optional-post',
    'description'   => esc_html__( 'This is Optional Sidebar for Post', 'magzimum' ),
    'before_widget' => '<aside id="%1$s" class="widget %2$s"><div class="widget-wrap">',
    'after_widget'  => '</div><!-- .widget-wrap --></aside><!-- #widget-default-search -->',
    'before_title'  => '<h4 class="widget-title">',
    'after_title'   => '</h4>',
  ) );

  //Optional Sidebar one for page and post
  register_sidebar( array(
    'name'          => esc_html__( 'Optional Sidebar One', 'magzimum' ),
    'id'            => 'sidebar-optional-one',
    'description'   => esc_html__( 'This is Optional Sidebar One', 'magzimum' ),
    'before_widget' => '<aside id="%1$s" class="widget %2$s"><div class="widget-wrap">',
    'after_widget'  => '</div><!-- .widget-wrap --></aside><!-- #widget-default-search -->',
    'before_title'  => '<h4 class="widget-title">',
    'after_title'   => '</h4>',
  ) );

  //Optional Sidebar two for page and post
  register_sidebar( array(
    'name'          => esc_html__( 'Optional Sidebar Two', 'magzimum' ),
    'id'            => 'sidebar-optional-two',
    'description'   => esc_html__( 'This is Optional Sidebar Two', 'magzimum' ),
    'before_widget' => '<aside id="%1$s" class="widget %2$s"><div class="widget-wrap">',
    'after_widget'  => '</div><!-- .widget-wrap --></aside><!-- #widget-default-search -->',
    'before_title'  => '<h4 class="widget-title">',
    'after_title'   => '</h4>',
  ) );

  //Optional Sidebar Three for page and post
  register_sidebar( array(
    'name'          => esc_html__( 'Optional Sidebar Three', 'magzimum' ),
    'id'            => 'sidebar-optional-three',
    'description'   => esc_html__( 'This is Optional Sidebar Three', 'magzimum' ),
    'before_widget' => '<aside id="%1$s" class="widget %2$s"><div class="widget-wrap">',
    'after_widget'  => '</div><!-- .widget-wrap --></aside><!-- #widget-default-search -->',
    'before_title'  => '<h4 class="widget-title">',
    'after_title'   => '</h4>',
  ) );

  // Registering 404 Error Page Content
  register_sidebar( array(
    'name'          => esc_html__( '404 Page Not Found Content', 'magzimum' ),
    'id'            => 'sidebar-notfound',
    'description'   => esc_html__( 'Replaces the default 404 Page Not Found Content', 'magzimum' ),
    'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<h2 class="widget-title">',
    'after_title'   => '</h2>',
  ) );


  register_sidebar( array(
    'name'          => esc_html__( 'Header Right Widget Area', 'magzimum' ),
    'id'            => 'sidebar-header-right-widget-area',
    'description'   => '',
    'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
  ) );
  register_sidebar( array(
    'name'          => esc_html__( 'Slider Right Widget Area', 'magzimum' ),
    'id'            => 'sidebar-slider-right-widget-area',
    'description'   => '',
    'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
  ) );
  //Promotion Headline Left
  register_sidebar( array(
    'name'          => esc_html__( 'Promotion Headline Left', 'magzimum' ),
    'id'            => 'promotion-headline-left',
    'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
    'description' => esc_html__( 'This is the Promotion Headline Left. Enable it by going to Appearance => Customize => Theme Options => Promotion Headline.', 'magzimum' ),
  ) );

  //Promotion Headline Right
  register_sidebar( array(
    'name'          => esc_html__( 'Promotion Headline Right', 'magzimum' ),
    'id'            => 'promotion-headline-right',
    'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
    'description' => esc_html__( 'This is the Promotion Headline Right. Enable it by going to Appearance => Customize => Theme Options => Promotion Headline.', 'magzimum' ),
  ) );
	register_sidebar( array(
		'name'          => esc_html__( 'Front Page Widget Area', 'magzimum' ),
		'id'            => 'sidebar-front-page-widget-area',
		'description'   => '',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

  register_sidebar( array(
    'name'          => esc_html__( 'Category Block One Widget Area', 'magzimum' ),
    'id'            => 'category-block-one-sidebar',
    'description'   => esc_html__( 'This is the Category Block One Widget Area for Category Block One section.', 'magzimum' ),
    'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
  ) );

  register_sidebar( array(
    'name'          => esc_html__( 'Instagram Widget Area', 'magzimum' ),
    'id'            => 'instagram-widget',
    'description'   => esc_html__( 'This is a footer Instagram widget area. It typically appears on the bottom of site before footer starts. It can be best used to display instagram feeds or advertisement Image.', 'magzimum' ), 
    'before_widget' => '<aside id="%1$s" class="widget %2$s">',
    'after_widget'  => '</aside>',
    'before_title'  => '<h3 class="widget-title">',
    'after_title'   => '</h3>',
  ) );
}
add_action( 'widgets_init', 'magzimum_widgets_init' );

/**
 * Enqueue scripts and styles.
 */
function magzimum_scripts() {
  wp_enqueue_style( 'magzimum-bootstrap', get_template_directory_uri() . '/assets/css/bootstrap.min.css', '', '3.3.4' );

  wp_enqueue_style( 'magzimum-fontawesome', get_template_directory_uri() . '/third-party/font-awesome/css/font-awesome.min.css', '', '4.3' );

  $magzimum_fonts  = array();
  $magzimum_fonts[]  = magzimum_get_option( 'body_font' );
  $magzimum_fonts[]  = magzimum_get_option( 'title_font' );
  $magzimum_fonts[]  = magzimum_get_option( 'tagline_font' );
  $magzimum_fonts[]  = magzimum_get_option( 'content_title_font' );
  $magzimum_fonts[]  = magzimum_get_option( 'content_font' );
  $magzimum_fonts[]  = magzimum_get_option( 'headings_font' );

  $web_fonts = array(
    'allan'             => 'Allan',
    'allerta'           => 'Allerta',
    'amaranth'          => 'Amaranth',
    'amaranth'          => 'Amaranth',
    'arvo'              => 'Arvo',
    'bitter'            => 'Bitter',
    'balthazar'         => 'Balthazar',
    'cabin'             => 'Cabin',
    'cantarell'         => 'Cantarell',
    'crimson-text'      => 'Crimson+Text',
    'cuprum'            => 'Cuprum',
    'dancing-script'    => 'Dancing+Script',
    'droid-sans'        => 'Droid+Sans',
    'droid-serif'       => 'Droid+Serif',
    'exo'               => 'Exo',
    'exo-2'             => 'Exo+2',
    'istok-web'         => 'Istok+Web',
    'lato'              => 'Lato',
    'lobster'           => 'Lobster',
    'lora'              => 'Lora',
    'montserrat'        => 'Montserrat',
    'nobile'            => 'Nobile',
    'noto-serif'        => 'Noto+Serif',
    'neuton'            => 'Neuton',
    'open-sans'         => 'Open+Sans',
    'oswald'            => 'Oswald',
    'patua-one'         => 'Patua+One',
    'playfair-display'  => 'Playfair+Display',
    'pt-sans'           => 'PT+Sans',
    'pt-serif'          => 'PT+Serif',
    'quattrocento-sans' => 'Quattrocento+Sans',
    'roboto'            => 'Roboto',
    'roboto-slab'       => 'Roboto+Slab',
    'source-sans-pro'   => 'Source+Sans+Pro',
    'ubuntu'            => 'Ubuntu',
    'yanone-kaffeesatz' => 'Yanone+Kaffeesatz'
  );

  $magzimum_fonts = array_unique( $magzimum_fonts ); // Make the array of fonts unique so that same font is not loaded twice
  $magzimum_fonts = array_intersect( $magzimum_fonts, array_keys( $web_fonts ) ); // Intersect selected fonts and webfonts to only recover fonts that need loading

  if ( empty( $options[ 'reset_typography' ] ) && !empty( $magzimum_fonts ) ) {
    $web_fonts_stylesheet = '//fonts.googleapis.com/css?family=';

    $i  = 0;
    foreach( $magzimum_fonts as $magzimum_fonts ) {
      if( $i )// only set | to $web_fonts_stylesheet from second loop onwards
        $web_fonts_stylesheet .='|';

      $web_fonts_stylesheet .= $web_fonts[ $magzimum_fonts ] . ':300,300italic,regular,italic,400,600,600italic,700';

      $i = 1;
    }

    $web_fonts_stylesheet .= '&subset=latin';

    wp_register_style( 'magzimum-web-font', $web_fonts_stylesheet, false, null );

    $magzimum_deps = array( 'magzimum-web-font' );
  }
  else {
    $magzimum_deps = false;
  }

  wp_enqueue_style( 'magzimum-style', get_stylesheet_uri(), $magzimum_deps );

  $magzimum_theme_color = magzimum_get_option('magzimum_theme_color');
  // Add default style
  wp_enqueue_style( 'magzimum-theme-color', get_template_directory_uri() . '/assets/css/'.$magzimum_theme_color.'.css', array( 'magzimum-style' ), false );

  wp_enqueue_style( 'magzimum-mmenu-style', get_template_directory_uri() .'/third-party/mmenu/css/jquery.mmenu.css', '', '4.7.5' );

  wp_enqueue_style( 'magzimum-owl-carousel-style', get_template_directory_uri() .'/third-party/owl-carousel/css/owl.carousel.css', '', '2.0' );

  wp_enqueue_style( 'magzimum-responsive-style', get_template_directory_uri() .'/assets/css/responsive.css', '', '1.0.0' );

  wp_enqueue_script( 'magzimum-placeholder', get_template_directory_uri() . '/assets/js/jquery.placeholder.js', array( 'jquery' ), '2.0.9', true );

  wp_enqueue_script( 'magzimum-navigation', get_template_directory_uri() . '/assets/js/navigation.js', array(), '20120206', true );

  $go_to_top = magzimum_get_option( 'go_to_top' );
  if ( 1 == $go_to_top ) {
  	wp_enqueue_script( 'magzimum-goto-top', get_template_directory_uri() . '/assets/js/goto-top.js', array( 'jquery' ), '1.0.0', true );
  }

  wp_enqueue_script( 'magzimum-skip-link-focus-fix', get_template_directory_uri() . '/assets/js/skip-link-focus-fix.js', array(), '20130115', true );
  
  // Load the html5shiv.
  wp_enqueue_script( 'magzimum-html5shiv', get_template_directory_uri() . '/assets/js/html5shiv.js', array(), '3.7.3' );
  wp_script_add_data( 'magzimum-html5shiv', 'conditional', 'lt IE 9' );

  // Load the html5shiv.
  wp_enqueue_script( 'magzimum-respond', get_template_directory_uri() . '/assets/js/respond.js', array(), '' );
  wp_script_add_data( 'magzimum-respond', 'conditional', 'lt IE 9' );

  wp_enqueue_script( 'magzimum-cycle2-script', get_template_directory_uri() . '/third-party/cycle2/js/jquery.cycle2.min.js', array( 'jquery' ), '2.1.6', true );

  wp_enqueue_script( 'jquery-cycle2-carousel', get_template_directory_uri() . '/third-party/cycle2/js/jquery.cycle2.carousel.min.js', array( 'jquery' ), '20141007', true );
  
  wp_enqueue_script( 'magzimum-easytabs-script', get_template_directory_uri() . '/third-party/easytabs/js/jquery.easytabs.min.js', array( 'jquery' ), '3.2.0', true );

  wp_enqueue_script( 'magzimum-ticker-script', get_template_directory_uri() . '/third-party/ticker/jquery.easy-ticker.min.js', array( 'jquery' ), '2.0', true );

  wp_enqueue_script( 'magzimum-owl-carousel-script', get_template_directory_uri() . '/third-party/owl-carousel/js/owl.carousel.min.js', array( 'jquery' ), '2.0', false );

  wp_enqueue_script( 'magzimum-mmenu-script', get_template_directory_uri() . '/third-party/mmenu/js/jquery.mmenu.min.js', array( 'jquery' ), '4.7.5', true );

	wp_enqueue_script( 'magzimum-custom-js', get_template_directory_uri() . '/assets/js/custom.js', array( 'jquery' ), '1.0.0', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}
}
add_action( 'wp_enqueue_scripts', 'magzimum_scripts' );


/**
 * Enqueue admin scripts and styles.
 */
function magzimum_admin_scripts( $hook ) {

  if ( 'widgets.php' == $hook ) {
    wp_enqueue_media();
    wp_enqueue_style( 'magzimum-widgets-style', get_template_directory_uri() .'/assets/css/widgets.css', '', '1.0.0' );
    wp_enqueue_script( 'magzimum-widgets-script', get_template_directory_uri() . '/assets/js/widgets.js', array( 'jquery' ), '1.0.0' );
  }

}
add_action( 'admin_enqueue_scripts', 'magzimum_admin_scripts' );

/**
 * Implement the Custom Header feature.
 */
require get_template_directory() . '/inc/custom-header.php';

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require get_template_directory() . '/inc/extras.php';

/**
 * Customizer additions.
 */
require get_template_directory() . '/inc/customizer.php';

/**
 * Load Jetpack compatibility file.
 */
require get_template_directory() . '/inc/jetpack.php';
/**
 * Load Custom and inline css file.
 */
require get_template_directory() . '/inc/hook/core.php';
