<?php

add_filter( 'magzimum_filter_default_theme_options', 'magzimum_category_block_one_default_options' );

/**
 * category block one defaults.
 *
 * @since  Magzimum Pro 1.5
 */
if( ! function_exists( 'magzimum_category_block_one_default_options' ) ):

  function magzimum_category_block_one_default_options( $input ){

    $input['category_block_one_status']           = 'disabled';
    $input['category_block_one_title']            = esc_html__( 'Culture', 'magzimum' );
    $input['num_of_category_block_one']           = 4;
    $input['category_block_one_content_category'] = '';
    $input['category_block_one_type']			  = 'featured-category';

    return $input;
  }

endif;



add_filter( 'magzimum_theme_options_args', 'magzimum_category_block_one_theme_options_args' );


/**
 * Add category block one options.
 *
 * @since  Magzimum Pro 1.5
 */

if( ! function_exists( 'magzimum_category_block_one_theme_options_args' ) ):

  function magzimum_category_block_one_theme_options_args( $args ){

    // Create category block one option panel
    $args['panels']['category_block_one_panel']['title'] = esc_html__( 'Category Block One', 'magzimum' );

    // Settings Section
    $args['panels']['category_block_one_panel']['sections']['section_category_block_one_type'] = array(
	      'title'    => esc_html__( 'Category Block One Type', 'magzimum' ),
	      'priority' => 70,
	      'fields'   => array(
	        'category_block_one_status' => array(
	          'title'   => esc_html__( 'Enable on', 'magzimum' ),
	          'type'    => 'select',
	          'choices' => magzimum_get_featured_status_options(),
	          'priority'=>  1,
	        ),
	        'category_block_one_type' => array(
	          'title'             => esc_html__( 'Select Category Block One Type', 'magzimum' ),
	          'type'              => 'select',
	          'choices'           => magzimum_get_category_block_one_type(),
	          'sanitize_callback' => 'sanitize_key',
	          'priority'          =>  2,
	        ),
	        'category_block_one_title' => array(
	          'title' => esc_html__( 'Title', 'magzimum' ),
	          'type'  => 'text',
	          'priority'          =>  3,
	        ),
	        'num_of_category_block_one' => array(
	          'title'             => esc_html__( 'Number of Posts', 'magzimum' ),
	          'type'              => 'number',
	          'sanitize_callback' => 'absint',
	          'priority'          =>  4,
	          'input_attrs'       => array(
	                                'min'   => 1,
	                                'max'   => 4,
	                                'step'  => 1,
	                                'style' => 'width: 50px;'
	                                ),
	        ),
		)
	);

    return $args;
  }

endif;


add_action( 'customize_register', 'magzimum_category_block_one_loop_options' );
/**
 * Add category block one post, category loop
 *
 * @since  Magzimum Pro 1.5
 */

if( ! function_exists( 'magzimum_category_block_one_loop_options' ) ):

  	function magzimum_category_block_one_loop_options( $wp_customize ){


  		// Add featured story category setting and control.
		$wp_customize->add_setting(  'theme_options[category_block_one_content_category]', array(
			'sanitize_callback' => 'absint',
		) ) ;

		$wp_customize->add_control( new Magzimum_Customize_Dropdown_Taxonomies_Control ( $wp_customize,'theme_options[category_block_one_content_category]', array(
			'active_callback'	=> 'magzimum_is_category_block_one_content_category',
			'label'             => esc_html__( 'Dropdown Category Control', 'magzimum' ),
			'section'           => 'section_category_block_one_type',
			'type'              => 'dropdown-taxonomies',
		) ) );

	    $num_of_category_block_one   = magzimum_get_option( 'num_of_category_block_one' );

	    for ( $i=1; $i <= $num_of_category_block_one; $i++ ) {
	      //Featured Post
	      	$wp_customize->add_setting( 'theme_options[category_block_one_post_'. $i .']', array(
	          'capability'        => 'edit_theme_options',
	          'sanitize_callback' => 'absint', 
	        ) 
	      	);

	      	$wp_customize->add_control( 'theme_options[category_block_one_post_'. $i .']', array(
	        'active_callback'   => 'magzimum_is_category_block_one_post_slider_active',
	        'input_attrs'         => array(
	            'style' => 'width: 100px;'
	          ),
	        'label'             => esc_html__( 'Featured Post ID', 'magzimum' ) . ' ' . $i ,
	        'priority'          =>  '4' . $i,
	        'section'           => 'section_category_block_one_type',
	        'settings'          => 'theme_options[category_block_one_post_'. $i .']',
	        'type'              => 'text',
	        )
	      	);
    	}
	}
endif;


if( ! function_exists( 'magzimum_is_category_block_one_post_slider_active' ) ) :
  /**
  * Return true if featured post content is active
  *
  * @since  Magzimum Pro 1.5
  */
  function magzimum_is_category_block_one_post_slider_active( $control ) {
    $category_block_one_type = $control->manager->get_setting( 'theme_options[category_block_one_type]' )->value();

    //return true only if previwed page on customizer matches the type of slider option selected
    return ( 'featured-post' == $category_block_one_type );
  }
endif;


if( ! function_exists( 'magzimum_is_category_block_one_content_category' ) ) :
  /**
  * Return true if featured post content is active
  *
  * @since  Magzimum Pro 1.5
  */
  function magzimum_is_category_block_one_content_category( $control ) {
    $category_block_one_type = $control->manager->get_setting( 'theme_options[category_block_one_type]' )->value();

    //return true only if previwed page on customizer matches the type of slider option selected
    return ( 'featured-category' == $category_block_one_type );
  }
endif;