<?php

add_filter( 'magzimum_filter_default_theme_options', 'magzimum_promotion_headline_default_options' );

/**
 * Header Image defaults.
 *
 * @since  Magzimum 1.0
 */
if( ! function_exists( 'magzimum_promotion_headline_default_options' ) ):

  function magzimum_promotion_headline_default_options( $input ){
    $input['promotion_headline_option']     = 'disabled';
    $input['promotion_headline_left_width'] = '80';
    $input['promotion_headline']            = esc_html__( 'Magzimum Pro is a Responsive WordPress Theme', 'magzimum' );
    $input['promotion_subheadline']         = esc_html__( 'This is promotion sub headline.', 'magzimum' );
    $input['promotion_headline_button']     = esc_html__( 'Buy Now', 'magzimum' );
    $input['promotion_headline_url']        = esc_url( 'http://themepalace.com/' );
    $input['promotion_headline_target']     = 1;

    return $input;
  }

endif;


add_filter( 'magzimum_theme_options_args', 'magzimum_promotion_headline_theme_options_args' );

/**
 * Add Header Image options.
 *
 * @since  Magzimum 1.0
 */

if( ! function_exists( 'magzimum_promotion_headline_theme_options_args' ) ):

  function magzimum_promotion_headline_theme_options_args( $args ){
    // Settings Section
    $args['panels']['theme_option_panel']['sections']['promotion_headline'] = array(
      'title'       => esc_html__( 'Promotion Headline', 'magzimum' ),
      'description' => esc_html__( 'To disable the fields, simply leave them empty.', 'magzimum' ),
      'priority'    => 70,
      'fields'      => array(
        'promotion_headline_option' => array(
          'title'             => esc_html__( 'Enable Promotion Headline on', 'magzimum' ),
          'type'              => 'select',
          'choices'           => magzimum_get_featured_status_options(),
          'sanitize_callback' => 'sanitize_key',
        ),
        'promotion_headline' => array(
          'description'       => esc_html__( 'Appropriate Words: 10', 'magzimum' ),
          'title'             => esc_html__( 'Promotion Headline Text', 'magzimum' ),
          'type'              => 'textarea',
          'sanitize_callback' => 'wp_kses_post',
        ),
        'promotion_subheadline' => array(
          'description'       => esc_html__( 'Appropriate Words: 15', 'magzimum' ),
          'title'             => esc_html__( 'Promotion Subheadline Text', 'magzimum' ),
          'type'              => 'textarea',
          'sanitize_callback' => 'wp_kses_post',
        ),
        'promotion_headline_button' => array(
          'description'       => esc_html__( 'Appropriate Words: 3', 'magzimum' ),
          'title'             => esc_html__( 'Promotion Headline Button Text ', 'magzimum' ),
          'type'              => 'text',
          'sanitize_callback' => 'sanitize_text_field',
        ),
        'promotion_headline_url' => array(
          'title'             => esc_html__( 'Promotion Headline Link', 'magzimum' ),
          'type'              => 'text',
          'sanitize_callback' => 'esc_url_raw'
        ),
        'promotion_headline_target' => array(
          'title' => esc_html__( 'Check to Open Link in New Window/Tab', 'magzimum' ),
          'type'  => 'checkbox',
        ),
        'promotion_headline_left_width' => array(
          'title'       => esc_html__( 'Promotion Headline Left Section Width', 'magzimum' ),
          'description' => esc_html__( 'This is promotion headline left section width. Once this is adjusted, the width for promotion headline right section is set automatically. in %', 'magzimum' ),
          'type'          => 'number',
          'input_attrs' => array(
            'min'   => 10,
            'max'   => 100,
            'style' => 'width: 50px;'
            ),
          'sanitize_callback' => 'magzimum_sanitize_number_range'
        ),
      )
    );

  return $args;
  }

endif;


/**
 * Number Range sanitization callback example.
 *
 * - Sanitization: number_range
 * - Control: number, tel
 * 
 * Sanitization callback for 'number' or 'tel' type text inputs. This callback sanitizes
 * `$number` as an absolute integer within a defined min-max range.
 * 
 * @see absint() https://developer.wordpress.org/reference/functions/absint/
 *
 * @param int                  $number  Number to check within the numeric range defined by the setting.
 * @param WP_Customize_Setting $setting Setting instance.
 * @return int|string The number, if it is zero or greater and falls within the defined range; otherwise,
 *                    the setting default.
 */
function magzimum_sanitize_number_range( $number, $setting ) {

  // Ensure input is an absolute integer.
  $number = absint( $number );
  
  // Get the input attributes associated with the setting.
  $atts = $setting->manager->get_control( $setting->id )->input_attrs;
  
  
  // Get minimum number in the range.
  $min = ( isset( $atts['min'] ) ? $atts['min'] : $number );
  
  // Get maximum number in the range.
  $max = ( isset( $atts['max'] ) ? $atts['max'] : $number );
  
  // Get step.
  $step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );
  
  // If the number is within the valid range, return it; otherwise, return the default
  return ( $min <= $number && $number <= $max && is_int( $number / $step ) ? $number : $setting->default );
}
