<?php
/**
 * Category Block One section
 *
 * This is the template for the content of Category Block One section in front page
 *
 * @package Theme Palace
 * @subpackage Magzimum Pro
 * @since Magzimum Pro 1.5
 */

// Check status
add_filter( 'magzimum_filter_category_block_one_status', 'magzimum_check_category_block_one_status' );

if ( ! function_exists( 'magzimum_add_category_block_one_section' ) ) :
    /**
     * Add Category Block One section
     *
     * @since 1.5
     */
    function magzimum_add_category_block_one_section() {

        // Check if Category Block One is enabled 
        $category_block_one_enable = apply_filters( 'magzimum_filter_category_block_one_status', true, 'category_block_one_enable' );
        if ( true !== $category_block_one_enable ) {
            return false;
        }

        // Get Category Block One section details
        $section_details = array();
        $section_details = apply_filters( 'magzimum_filter_category_block_one_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render Category Block One section now.
        magzimum_render_category_block_one_section( $section_details );
    }
endif;
add_action( 'magzimum_action_before_content', 'magzimum_add_category_block_one_section', 7 );


if ( ! function_exists( 'magzimum_get_category_block_one_section_details' ) ) :
    /**
     * category block One section details.
     *
     * @since 1.5
     *
     * @param array $input category block One section details.
     */
    function magzimum_get_category_block_one_section_details( $input ) {

        $content = array();
        $no_of_post = absint( magzimum_get_option('num_of_category_block_one') );

        switch ( magzimum_get_option('category_block_one_type') ) {
            
            case 'featured-category':
                $category_block_one_content_category = magzimum_get_option('category_block_one_content_category');
                $category = !empty ( $category_block_one_content_category ) ? absint( $category_block_one_content_category ) : '';
                
                if ( ! empty( $category ) ) {
                
                    $args = array(
                        'cat'               => $category,
                        'posts_per_page'    => $no_of_post
                    );
                }
            break;

            case 'featured-post':
                $post_list = array();
                for ( $i = 1; $i <= $no_of_post ; $i++ ) { 
                    $category_block_one_post_id = magzimum_get_option( 'category_block_one_post_id_' . $i );
                    $post_id    = ! empty ( $category_block_one_post_id ) ? absint( $category_block_one_post_id ) : '';
                    $post_list  = array_merge( $post_list, array( $post_id ) );
                }

                if ( ! empty( $post_list ) ) {
                
                    $args = array(
                        'post__in'           => $post_list,
                        'posts_per_page'    => $no_of_post,
                    );
                }
            break;

            default:
            break;          
        }
            
        if( ! empty ( $args ) ) :
            
            
            $custom_posts = get_posts( $args );

            $i = 0;
            foreach ( $custom_posts as $key => $custom_post ) {
                
                $img_array = null;

                if ( has_post_thumbnail( $custom_post->ID ) ) {
                    $img_array = wp_get_attachment_image_src( get_post_thumbnail_id( $custom_post->ID ), 'magzimum-featured' );
                    $content[$i]['img_array'] = $img_array;
                } 

                $content[$i]['url']      = get_permalink( $custom_post->ID );
                $content[$i]['title']    = get_the_title( $custom_post->ID );
                $content[$i]['excerpt']  = magzimum_get_the_excerpt( 20, $custom_post );
                $content[$i]['date']     = get_the_date( '', $custom_post->ID );
            $i++;
            }
        endif;
    
        if ( ! empty( $content ) ) {
            $input = $content;
        }
    return $input;      
    }
endif;
// category block One section content details.
add_filter( 'magzimum_filter_category_block_one_section_details', 'magzimum_get_category_block_one_section_details' );

if ( ! function_exists( 'magzimum_render_category_block_one_section' ) ) :
    /**
     * Start section category block One
     *
     * @return string category block One content
     * @since Magzimum Pro 1.5
     *
     */
    function magzimum_render_category_block_one_section( $content_details = array() ) {

        if ( empty( $content_details ) ) {
            return;
        } 
        if( is_active_sidebar( 'category-block-one-sidebar' ) ) :
            $magzimum_no_section_sidebar   = '';
        else :
            $magzimum_no_section_sidebar   = 'no-section-sidebar';
        endif;
        ?>

        <section id="culture" class="<?php echo esc_attr( $magzimum_no_section_sidebar ); ?>">
            <?php $section_title = magzimum_get_option('category_block_one_title');
            if(! empty( $section_title ) ) : ?>
            <div class="container page-section">
                <div class="main-content widget-category">
                   <header class="entry-header">
                      <h2 class="entry-title color-black"><?php echo esc_html( $section_title );?></h2>
                  </header><!-- end .entry-header -->
                <?php endif; ?>
                    
                    <?php foreach( $content_details as $content) :
                    $class = !empty( $content['img_array'][0] ) ? '' : 'no-post-thumbnail';?>
                    <div class="blog-post <?php echo esc_attr( $class ); ?>">
                        <?php if( !empty( $content['img_array'][0] ) ) : ?>
                        <div class="category-image">
                          <a href="<?php echo esc_url( $content['url'] );?>"><img src="<?php echo esc_url( $content['img_array'][0] ); ?>" alt="<?php echo esc_html( $content['title'] ); ?>">
                          <div class="overlay-red"></div></a>
                        </div>
                        <?php endif; ?>
                     
                        <div class="category-desc">
                            <?php if( !empty( $content['date'] ) ) : ?>
                          <span class="date"><?php echo esc_html( $content['date'] ); ?></span>
                            <?php endif; ?>
                            
                            <?php if( !empty( $content['title'] ) ) : ?>
                          <a href="<?php echo esc_url( $content['url'] );?>">
                          <h2><?php echo esc_html( $content['title'] ); ?></h2></a>
                            <?php endif; ?>
                          
                            <?php if( !empty( $content['excerpt'] ) ) : ?>
                            <p><?php echo esc_html( $content['excerpt'] ); ?></p>
                            <?php endif; ?>

                            <?php if( !empty( $content['excerpt'] ) ) : ?>
                              <a href="<?php echo esc_url( $content['url'] ); ?>" class="read-more"><?php echo esc_html( magzimum_get_option('read_more_text') ); ?></a>
                            <?php endif; ?>
                        </div><!-- end .category-desc -->
                        <div class="clear"></div>
                    </div><!-- end .blog-post-->
                    <?php endforeach; ?>
                </div><!-- end .main-content-->
                <?php
                    if( is_active_sidebar( 'category-block-one-sidebar' ) ) : ?>
                        <div class="sidebar bg-white">
                            <?php dynamic_sidebar( 'category-block-one-sidebar' ); ?>
                        </div><!-- end .sidebar -->
                    <?php endif;  
                ?>
                </div><!-- .container -->
            <div class="clear"></div>
        </section><!-- end #culture -->
<?php
    }
endif;


/**
 * Check status of featured story.
 *
 * @since Magzimum 1.5
 *
 */
if( ! function_exists( 'magzimum_check_category_block_one_status' ) ):

    function magzimum_check_category_block_one_status( $input ){

    // Featured status
    $category_block_one_status = magzimum_get_option( 'category_block_one_status' );

    // Initial
    $status = false;

    switch ( $category_block_one_status ) {

      case 'entire-site':
        $status = true;
        break;

      case 'home-page-only':
        if ( is_front_page() ) {
          $status = true;
        }
        break;

      case 'home-blog-page':
        if ( is_front_page() || is_home() ) {
          $status = true;
        }
        break;

      case 'disabled':
      default:
        $status = false;
        break;
    }
    return $status;
    }
endif;