<?php

/**
 * Add custom CSS
 *
 * @since  Magzimum 1.0
 */

if( ! function_exists( 'magzimum_add_custom_css' ) ) :

  function magzimum_add_custom_css(){
    $custom_css  = '';
    //Add Promotion Headline Custom CSS
    $promotion_headline_left_width = magzimum_get_option( 'promotion_headline_left_width' );

    $title_font         = magzimum_get_option( 'title_font' );

    $body_font          = magzimum_get_option( 'body_font' );

    $tagline_font       = magzimum_get_option( 'tagline_font' );

    $content_title_font = magzimum_get_option( 'content_title_font' );

    $content_font       = magzimum_get_option( 'content_font' );

    $headings_font      = magzimum_get_option( 'headings_font' );

    $defaults           = magzimum_get_default_theme_options();

    //Get avaliable fonts
    $fonts              = magzimum_get_avaliable_fonts();

    if( 80 != $promotion_headline_left_width ) {
      $custom_css  .= "@media screen and (min-width: 768px) {". "\n";
      if ( 100 == $promotion_headline_left_width ) {
        $custom_css  .=  "#promotion-message .left, #promotion-message .right { max-width: 100%; width: 100%; }". "\n";
        $custom_css  .=  "#promotion-message .right .promotion-button { margin-top: 0; }". "\n";
      }
      else {
        $custom_css  .=  "#promotion-message .left { max-width: ". absint( $promotion_headline_left_width ) ."%; }". "\n";
      }
      $custom_css  .= "}". "\n";
    }

    /* Default Font Family */
    if( $defaults[ 'body_font' ] != $body_font ) {
      $custom_css .=  "body, button, input, select, textarea { font-family: ". $fonts [ $body_font ] ."; }". "\n";
    } 
    
    if( $defaults[ 'title_font' ] != $title_font ) {
      $custom_css .=  ".site-branding .site-title { font-family: ". $fonts [ $title_font ]  ."; }". "\n";
    }

    if( $defaults[ 'tagline_font' ] != $tagline_font ) {
      $custom_css .=  ".site-branding .site-description { font-family: ". $fonts [ $tagline_font ]  ."; }". "\n";
    }

    if( $defaults[ 'content_title_font' ] != $content_title_font ) {
      $custom_css .=  "#main .entry-header .entry-title, #main-featured-content h3, #main-slider h3, .page-title { font-family: ". $fonts [ $content_title_font ]  ."; }". "\n";
    }

    if( $defaults[ 'content_font' ] != $content_font ) {
      $custom_css .=  "#content { font-family: ". $fonts [ $content_font ]  ."; }". "\n";
    }

    if( $defaults[ 'headings_font' ] != $headings_font ) {
      $custom_css .=  "h1, h2, h3, h4, h5, h6 { font-family: ". $fonts [ $headings_font ]  ."; }". "\n";
    }
    
    $header_text_color = get_header_textcolor();
    // If no custom options for text are set, let's bail
    // get_header_textcolor() options: HEADER_TEXTCOLOR is default, hide text (returns 'blank') or any hex value
    if ( get_theme_support( 'custom-header', 'default-text-color' ) !== $header_text_color ) {

        // If we get this far, we have custom styles. Let's do this.
         // Has the text been hidden?
        if ( 'blank' == $header_text_color ) :
            $custom_css .='    
                .site-title,
                .site-description {
                    position: absolute;
                    clip: rect(1px, 1px, 1px, 1px);
                }';
        // If the user has set a custom color for the text use that
        else :
            $custom_css .='
                .site-title a,
                .site-description {
                    color: #'.esc_attr( $header_text_color ).';
                }';
        endif;
    }
       
    $custom_css .='
        .appearance_page_custom-header #headimg {
            border: none;
        }
        #headimg h1,
        #desc {
        }
        #headimg h1 {
        }
        #headimg h1 a {
        }
        #desc {
        }
        #headimg img {
        }';

    $magzimum_custom_css = '';
    $magzimum_css = '';
    $css = '';

    // Check if the custom CSS feature of 4.7 exists
    if ( function_exists( 'wp_update_custom_css_post' ) ) {
        // Migrate any existing theme CSS to the core option added in WordPress 4.7.
        if( !empty( magzimum_get_option( 'custom_css' ) ) )
            $css = magzimum_get_option( 'custom_css' );
        
        if ( $css ) {
            $core_css = wp_get_custom_css(); // Preserve any CSS already added to the core option.
            $return = wp_update_custom_css_post( $core_css . $css );
        
            if ( ! is_wp_error( $return ) ) {
                // Remove the old theme_mod, so that the CSS is stored in only one place moving forward.
            $input['custom_css']         = '';
            set_theme_mod( 'theme_options', $input );
            }
        }
    } else {
        // Back-compat for WordPress < 4.7.
        $magzimum_css = magzimum_get_option( 'custom_css' );
        if ( isset( $magzimum_css ) ) {
            $magzimum_custom_css = magzimum_get_option( 'custom_css' );
        }
    }
    $custom_css .= $magzimum_custom_css;
    wp_add_inline_style( 'magzimum-theme-color', $custom_css );
  }
endif;
add_action( 'wp_enqueue_scripts', 'magzimum_add_custom_css', 10 );

